@@ -223,9 +223,9 @@ def addText2Img_cv2(img_cv2,text,font=_FONT,position=(20,20),fill=(255,0,0)):
     img_PIL = Image.fromarray(cv2.cvtColor(img_cv2,cv2.COLOR_BGR2RGB))#cv2.COLOR_BGR2RGB cv2.COLOR_RGB2BGR
     draw = ImageDraw.Draw(img_PIL)
     draw.text(position, text, font=font, fill=fill)
-    img_cv2 = cv2.cvtColor(numpy.asarray(img_PIL),cv2.COLOR_RGB2BGR)# 转换回OpenCV格式
+    ret = cv2.cvtColor(numpy.asarray(img_PIL),cv2.COLOR_RGB2BGR)# 转换回OpenCV格式
     img_PIL.close()
-    return img_cv2
+    return ret
 
 def captureImageFromCam(camSerial=None):
     '''
@@ -299,6 +299,25 @@ def captureImageFromCamAndSave(tag,folder="train",camSerial=None):
     cv2.destroyAllWindows()
     return ret
 
+def predictImage(frame,db=DB,showResult=True):
+    '''
+    predictImage(frame,db=DB,showResult=True)
+    '''
+    rects=_detector(frame, 1)
+    Tags = [];dists = []
+    for rect in rects:
+        try:
+            V=getFeatureVector(frame,rect)
+            Tag,dist=predictFromDB(V,db) # predict the target Tag
+            Tags.append(Tag);dists.append(dist);rects.append(rect)
+            if showResult:
+                cv2.rectangle(frame,(rect.left(),rect.top()),(rect.right(),rect.bottom()),(255,0,0),3)
+                #cv2.putText(frame, Tag+":"+str(dist),, cv2.FONT_HERSHEY_SIMPLEX,1, (255, 0, 0), 2, cv2.LINE_AA)
+                text=Tag+":"+str(dist)
+                frame=addText2Img_cv2(frame,Tag+":"+str(round(dist,3)),_FONT,(rect.left(), rect.top()-_FONT.size-1))
+        except IndexError:pass
+    return Tags,dists,rects,frame
+    
 def predictCam(camSerial=None,skipFranmes=1,outputFileName="",db=DB):
     '''
         predictCam(camSerial=None,skipFranmes=1,outputFileName="")
@@ -317,29 +336,23 @@ def predictCam(camSerial=None,skipFranmes=1,outputFileName="",db=DB):
             if cap.isOpened():break
     else: cap = cv2.VideoCapture(camSerial)
     cv2.startWindowThread()
-    _detector = dlib.get_frontal_face_detector()
+    #_detector = dlib.get_frontal_face_detector()
     count = 0
     while(True):    
         if not cap.isOpened():break
         ret, frame = cap.read()
         count+=1
         if count%skipFranmes!=0 :continue
-        if ret: 
-            try:
-                rects=_detector(frame, 1)
-                for rect in rects:
-                    V=getFeatureVector(frame,rect)
-                    Tag,dist=predictFromDB(V,db) # predict the target Tag
-                    cv2.rectangle(frame,(rect.left(),rect.top()),(rect.right(),rect.bottom()),(255,0,0),3)
-                    #cv2.putText(frame, Tag+":"+str(dist),, cv2.FONT_HERSHEY_SIMPLEX,1, (255, 0, 0), 2, cv2.LINE_AA)
-                    text=Tag+":"+str(dist)
-                    frame=addText2Img_cv2(frame,Tag+":"+str(round(dist,3)),_FONT,(rect.left(), rect.top()-_FONT.size-1))        
-                    if outputFileName!="":
-                        try:
-                            with open(outputFileName,'w',encoding='UTF-8') as f:
-                                f.write(Tag+'\t'+str(dist))
-                        except:print("file exception...")
-            except IndexError:pass    
+        if ret:
+            Tags,dists,rects,frame = predictImage(frame)
+            if outputFileName!="":
+                try:
+                    with open(outputFileName,'w',encoding='UTF-8') as f:
+                        for i in range(len(Tags)):
+                            rect = [rects[i].left(),rects[i].top(),rects[i].right(),rects[i].bottom()]
+                            f.write(Tags[i]+'\t'+str(dists[i])+'\t'+str(rect)+'\r\n' )
+                except:print("file exception...")
+            
             cv2.imshow('press esc to exit...', frame)
         if cv2.waitKey(10) == 27: break
     cap.release()
@@ -349,7 +362,6 @@ def predictVedio(vedioPath,skipFranmes=10,db=DB):
     '''
     predictVedio(vedioPath,skipFranmes=10,db=DB)
     skipFranmes: perform prediction every <skipFrames> frames
-    
     demo predicion from the vedio file
     press esc to exit
     '''
@@ -400,4 +412,4 @@ if __name__ == "__main__":
     #saveDB('features')
     #loadDBFromFeatureFiles("features")
     #print(DB['四葉草'])
-    #predictCam()
\ No newline at end of file
+    #predictCam(outputFileName="result.txt")
\ No newline at end of file
